# Crowdsourced Estimation of Collective Just Noticeable Difference for Compressed Video with Flicker Test and QUEST+

Please cite the following paper for the use of FlickerVidSet:
```
Mohsen Jenadeleh, Raouf Hamzaoui, Ulf-Dietrich Reips, and Dietmar Saupe, “Crowdsourced Estimation of Collective Just Noticeable Difference for Compressed Video with Flicker Test and QUEST+,” arXiv preprint arXiv:2203.00000,2023.

```

Please contact Mohsen Jenadeleh (mohsen.jenadeleh@uni-konstanz.de) if you have any questions.

## Description

### Source Sequences
The FlickerVidSet consists of 45 reference videos. The refrence videos have no audio. The duration of each reference is 5 seconds. These sequences are cropped from the VideoSet reference videos with 1920x1080 resolution.


The reference videos have the following format: 640 x 480, 30/24fps, YUV420p. These videos were cropped from 45 source videos with resolution 1920x1080 pixels from VideoSet [1].

The reference was losslessly encoded with QP=00. One can transcode it to YUV using the following script

```
ffmpeg -i ***_qp_00.264 -pix_fmt yuv420p -vcodec rawvideo ***.yuv
```

### Encoding Recipes

For  AVC compressed videos
```
ffmpeg -y -vcodec rawvideo -pix_fmt yuv420p -s:v $RESOLUTION -r $FPS -i $ORIG -c:v libx264 -x264opts qp=$QP:scenecut=0:bframes=3:b-adapt=2:b-pyramid=normal:ipratio=1.0:pbratio=1.0:aq-mode=0:qcomp=1.0:partitions=partp8x8,partb8x8,parti4x4:direct=auto:weightp=2:me=umh:merange=128:subme=9:psy=0:trellis=2:chroma-qp-offset=0:no-fast-pskip=1:threads=8:fps=$FPS:g=$GOP -psnr -f rawvideo $OUTPUT_VIDEO  
```
For VVC compressed videos
```
vvencFFapp --preset medium -i $INPUT_VIDEO  -c yuv420  -s $RESOLUTION  -r $FPS   -qpa 0 -q $QP    --IntraPeriod=64  --DecodingRefreshType=1  --RefreshSec=1  --profile main --format yuv420 -o   $OUTPUT_VIDEO  
```
For visually lossless compression with CRF = 12
```
ffmpeg -f rawvideo -s 640x480 -pixel_format yuv420p -framerate $FPS -i "$input_file" -c:v libx264 -preset veryslow -crf $CRF -g 24 -b_strategy 2 -bf 16 "$output_file.mp4"
```


### Distorted Clips

We employed the H.264/AVC high profile and H.266/VVC to encode each of the 45 sequences. For the primary bit rate control method, we selected the constant quantization parameter (QP), with QP values ranging from 1 to 51 for AVC, and from 1 to 63 for VVC.

### Encoding recipes
 For AVC encoded videos:
 
ffmpeg -y -vcodec rawvideo -pix_fmt yuv420p -s:v 640x480 -vsync 0 -r $FPS ​-pix_fmt yuv420p -i reference_video.yuv  -c:v libx264 -x264opts qp=$QP:GOP=24:scenecut=0:bframes=3:b-adapt=2:b-pyramid=normal:ipratio=1.0:pbratio=1.0:aq-mode=0:qcomp=1.0:partitions=partp8x8,partb8x8,parti4x4:direct=auto:weightp=2:me=umh:merange=128:subme=9:psy=0:trellis=2:chroma-qp-offset=0:no-fast-pskip=1:threads=8:fps=$FPS -psnr -f  output_video.mp4
_video 

For VVC encoded videos:


### Structure of VideoSet

The whole database consists of the following files:
```
1 FlickerVidSet.ZIP % Compressed sequence with AVC and VVC codecs.
2 45_Ref_videos_1920x1080_from_VideoSet.zip % 45 reference videos selected from VideoSet
3 subjective_data_FlickerVidSet.zip % subjective test data and the readme_v1.md
 ```
General name convention:
```
videoSRC{index}_{640x480}_{frame_rate}_qp_{QP}.mp4

index: \in {'001', '002', '004', ... '220'} % We used the same index was used for the chosen refrence videos from VideoSet
frame_rate: \in {'24', '30'}
QP: \in {'00', '01', ... '51'}  for the compressed video with AVC and  \in {'00', '01', ... '63'}  for the compressed video with VVC
```

Structure of sequence set:
```
|-- JND_{codec}_640x480
|	|-- videoSRC{index}_640x480_{frame_rate}
|		|--crf_12
|			|--flicker_test
|				|-- videoSRC{index}_640x480_{frame_rate}_qp_{00}_crf12.mp4 % reference video  
|				|-- videoSRC{index}_640x480_{frame_rate}_qp_00_{01}_crf12.mp4 % flickering videos for frequency 8 Hz between teh refrence and a compressed version
|				|-- videoSRC{index}_640x480_{frame_rate}_qp_00_{02}_crf12.mp4 % flickering videos
|			|--plain_test
|				|-- videoSRC{index}_640x480_{frame_rate}_qp_{00}_crf12.mp4  % reference video  
|				|-- videoSRC{index}_640x480_{frame_rate}_qp_{01}_crf12.mp4  % compressed videos
|				|-- videoSRC{index}_640x480_{frame_rate}_qp_{02}_crf12.mp4  % compressed videos

codec: in {'264','266'} for the H.264/AVC and H.266/VVC compressed videos
```

### Subjective Test Data

The subjective data for the flicker and plain test are avilable in  subjective_data_flicker_test.csv and subjective_data_plain_test.csv files.
* Video_ID: Id of teh source video
* codec type: \in {264 , 266} for H.264/AVC or H.266/VVC 
* presentation_type:  in {'plain test', flicker test'}
* qp_sequence: The QP values of the evaluated  sequence by QUEST+.  Only teh QP for the compressed videos are listed, the compressed videos were compared side-by-side with the refrence with Qp=0.
* side_of_reference_sequence: in each paired comparison, teh reference video with QP=0 was shown randomnly oin the  left "L" or right "R" side. The serence of  L and R listed corresponding to the same QP  in teh QP sequence.
* user_decision_sequence: The sequence of the user decision for each paired comparison. The user options were left "L", right "R", or not sure. 
* decision_code_sequence: In each paired comparison, the subjects were asked to select the side of the  flcikering video in teh flicker test anfd the video with teh lower quality in teh plain test. Therefore, if a subject chose the side of reference video, the decision is incorrect and coded with "1" , if the subject selected the side of the compressed video, the decison is correct and coded with "2", and  the "not sure" chose is coded with "3". 
* decison_time_sequence: The time between displaying of the paired video until a user press the "left", "right" or "not sure"  was recorded for each paired comparison. 

### Experiment methodology

We refer the user to [paper](arXivlink) for JND methodology, subjective test environment, data cleaning and experimental results.

#### Copyright Notice

 Permission is hereby granted, free of charge, to any person obtaining a copy of the database and associated documentation files, to deal in the database without restriction, including without limitation the rights to use, copy, modify, merge, publish or distribute  copies of this database.

#### External Links and References


The 45 reference video used in this study were cropped from VideoSet refrences with resolution 1920x1080.  
 [1] Wang, Haiqiang, Ioannis Katsavounidis, Jiantong Zhou, Jeonghoon Park, Shawmin Lei, Xin Zhou, Man-On Pun et al. "VideoSet: A large-scale compressed video quality dataset based on JND measurement." Journal of Visual Communication and Image Representation 46 (2017): 292-302.
https://www.sciencedirect.com/science/article/pii/S1047320317300950
https://ieee-dataport.org/keywords/just-noticeable-difference-jnd

Please not the copyright note for the VideoSet for using the 45 source videos published with our dataset:
"Copyright (c) 2017, University of Southern California
Permission is hereby granted, free of charge, to any person obtaining a copy of the database and associated documentation files (the "VIDEOSET DATABASE"), to deal in the database without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, and/or sell copies of the VIDEOSET DATABASE, and to permit persons to whom the dataset is furnished to do so, provided that the above copyright notice(s) and this paragraph and the following two paragraphs appear in all copies of the VIDEOSET DATABASE and in supporting documentation.

IN NO EVENT SHALL THE UNIVERSITY OF SOUTHERN CALIFORNIA BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THE VIDEOSET DATABASE, EVEN IF THE UNIVERSITY OF SOUTHERN CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

THE UNIVERSITY OF SOUTHERN CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT. THE VIDEOSET DATABASE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF SOUTHERN CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
"

Fraunhofer Versatile Video Encoder (VVenC) Software:
[2] Wieckowski, Adam, Jens Brandenburg, Tobias Hinz, Christian Bartnik, Valeri George, Gabriel Hege, Christian Helmrich et al. "VVenC: An open and optimized VVC encoder implementation." In 2021 IEEE International Conference on Multimedia & Expo Workshops (ICMEW), pp. 1-2. IEEE, 2021.
https://github.com/fraunhoferhhi/vvenc

